#-----------------------------------------------------------------------
# Set the following variables before includeing this file (shown with
# example settings):
#
#	ROOT_DIR=..
#	BOOK=config4star-getting-started-guide
#	TITLE="Config4* Getting Started Guide"
#	HAS_BIB=yes
#	HAS_GRAPHICS=no
#-----------------------------------------------------------------------

ifeq ($(USER),cjmchale)
WWW_DIR=/var/www-config4star.org
else
WWW_DIR=/var/www
endif

WWW_DOWNLOAD_DIR=$(WWW_DIR)/download
ETC_DIR=$(ROOT_DIR)/etc
SCRIPT_DIR=$(ROOT_DIR)/etc/scripts
LATEX_SUPPORT_FILES_DIR=$(ETC_DIR)/latex-support-files
WWW_BOOK_DIR=$(WWW_DIR)/$(BOOK)


.PHONY: default
default: copy-latex-support-files
	pdflatex $(BOOK).tex
ifeq ($(HAS_BIB),yes)
	bibtex $(BOOK)
endif
	$(MAKE) clean-latex-support-files

.PHONY: all
all: html pdf

.PHONY: pdf
pdf: clean
	$(MAKE) copy-latex-support-files
	pdflatex $(BOOK).tex
ifeq ($(HAS_BIB),yes)
	bibtex $(BOOK)
	pdflatex $(BOOK).tex
endif
	pdflatex $(BOOK).tex
	multidoc-2up $(BOOK).pdf
	mkdir -p  $(WWW_DOWNLOAD_DIR)/manuals
	chmod 775 $(WWW_DOWNLOAD_DIR)
	chmod 775 $(WWW_DOWNLOAD_DIR)/manuals
	cp $(BOOK).pdf     $(WWW_DOWNLOAD_DIR)/manuals
	cp $(BOOK)-2up.pdf $(WWW_DOWNLOAD_DIR)/manuals
	$(MAKE) clean-latex-support-files

.PHONY: html
html:	clean
	$(MAKE) copy-latex-support-files
	rm -f $(BOOK).aux
	hevea $(BOOK).tex
ifeq ($(HAS_BIB),yes)
	bibhva $(BOOK)
endif
ifeq ($(HAS_GRAPHICS),yes)
	-imagen -png -mag 2000 $(BOOK)
endif
	hevea $(BOOK).tex
	hacha -o index.html -tocbis $(BOOK).html
	hevea -o $(BOOK).html index.tex
	hacha -o index.html -tocbis $(BOOK).html
	tclsh $(SCRIPT_DIR)/hevea_insert_title.tcl index.html $(TITLE)
	tclsh $(SCRIPT_DIR)/hevea_fixup.tcl *.html
	-tidy -config $(ETC_DIR)/tidy.conf -m *.html
	tclsh $(SCRIPT_DIR)/hevea_insert_header_and_footer.tcl \
				-header $(ETC_DIR)/header.txt \
				-footer $(ETC_DIR)/footer.txt \
				*.html
	mkdir -p  $(WWW_BOOK_DIR)
	chmod 775 $(WWW_BOOK_DIR)
	cp *.html $(WWW_BOOK_DIR)
	cp $(ETC_DIR)/documentation.css $(WWW_BOOK_DIR)/$(BOOK).css
	-cp *.gif $(WWW_BOOK_DIR)
ifeq ($(HAS_GRAPHICS),yes)
	-cp *.png $(WWW_BOOK_DIR)
endif
	$(MAKE) clean-latex-support-files

.PHONY: copy-latex-support-files
copy-latex-support-files:
	cp $(LATEX_SUPPORT_FILES_DIR)/ch00-titlepage.tex .
	cp $(LATEX_SUPPORT_FILES_DIR)/commands.* .
	cp $(LATEX_SUPPORT_FILES_DIR)/config4star.bib .
	cp $(LATEX_SUPPORT_FILES_DIR)/framed.hva .
	cp $(LATEX_SUPPORT_FILES_DIR)/index.tex .
	cp $(LATEX_SUPPORT_FILES_DIR)/this-manual.hva .
	cat	$(LATEX_SUPPORT_FILES_DIR)/manual-start.txt \
		manual-contents.txt \
		$(LATEX_SUPPORT_FILES_DIR)/manual-end.txt \
	    > $(BOOK).tex

.PHONY: clean-latex-support-files
clean-latex-support-files:
	rm -f commands.* framed.hva this-manual.hva config4star.bib
	rm -f ch00-titlepage.tex index.tex $(BOOK).tex

.PHONY: clean
clean:	clean-latex-support-files
	rm -f *.aux *.log *.toc *.out *.dvi *.pdf *.blg
	rm -f *.haux *.htoc *.hbbl *.html *.gif *.css *.png
	rm -f $(BOOK).image.tex index.tex

clobber: clean
ifeq ($(HAS_BIB),yes)
	rm -f $(BOOK).bbl
endif
