
proc readFile {fileName} {
	if {[catch {
		set fd [open $fileName "r"]
		set contents [read $fd]
		close $fd
	} err]} {
		puts stderr $err
		exit 1
	}
	return $contents
}

proc writeFile {fileName contents} {
	if {[catch {
		set fd [open $fileName "w"]
		puts -nonewline $fd $contents
		close $fd
	} err]} {
		puts stderr $err
		exit 1
	}
}

proc processHtmlFile {fileName} {
	set contents [readFile $fileName]

	#--------
	# The entries in mapList do the following:
	# Line 1: Remove rules above and below figures
	# Lines 2 and 3: Remove empty last row in tables
	# Lines 4 and 5: Put some padding into cells in tables
	#--------
	set mapList [list \
		{<HR WIDTH="80%" SIZE=2>}		{} \
		{<TR><TD ALIGN=left NOWRAP></TD></TR>}	{} \
		{<TR><TD VALIGN=top ALIGN=left NOWRAP></TD></TR>} {} \
		{<TABLE BORDER=1 CELLSPACING=0 CELLPADDING=1>}	\
			{<TABLE BORDER=1 CELLSPACING=0 CELLPADDING=3>} \
	]
	set contents [string map $mapList $contents]

	#--------
	# Strip the hyperlink from cross references back to the "index.html".
	# Typically, these cross references are to "Part I", "Part II" and
	# so on. These can appear in the main text of the document and also
	# in the table of contents.
	#
	# Note: "\s" matches a whitespace character, so "\s*" matches
	# 0+ whitespace, and "\s+" matches 1+ whitespace characters.
	#--------
	regsub -all -nocase \
		{<a\s+href\s*=\s*["']index.html#[^>]*['"]\s*>([^<]*)</a>} \
		$contents {\1} contents
	# resync vim syntax highlightling "
	writeFile $fileName $contents
}

#--------
# Mainline
#--------
set prog [file tail $argv0]
foreach fileName $argv {
	puts "$prog: processing $fileName..."
	processHtmlFile $fileName
}
